import uvicorn
from fastapi import FastAPI
from fastapi.staticfiles import StaticFiles
import os

app = FastAPI()
if not os.path.exists('static'):
    os.mkdir('static')
app.mount("/static", StaticFiles(directory="static"), name="static")


def run():
    uvicorn.run("cameo_fastapi:app", host='0.0.0.0', port=20330, reload=True, debug=False, workers=1)



from setuptools import setup

setup(
    name='cameo_fastapi',
    version='0.2.3',
    description='CAMEO FastAPI, add main',
    url='https://github.com/bohachu/cameo_fastapi',
    author='Bowen Chiu',
    author_email='bohachu@gmail.com',
    license='BSD 0-clause license',
    packages=['cameo_fastapi'],
    install_requires=['uvicorn', 'fastapi', ],
    classifiers=['Programming Language :: Python :: 3']
)
